==> monodevelop_4.0.12+dfsg.orig.tar.gz: monodevelop-4.0.12/src/addins/MonoDevelop.DocFood/MonoDevelop.DocFood/IfStatement.cs <==
// 
// IfStatement.cs
//  
// Author:
//       Mike Krüger <mkrueger@novell.com>
// 
// Copyright (c) 2010 Novell, Inc (http://www.novell.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
using System;
using System.Xml;

namespace MonoDevelop.DocFood
{
	public class IfStatement : Node
	{
		public const string XmlTag = "If";
		
		public override void Run (DocGenerator generator, object member)
		{
			if (generator.EvaluateCondition (Attributes, member))
				Children.ForEach (child => child.Run (generator, member));
		}
		
		public override void Write (XmlWriter writer)
		{
			writer.WriteStartElement (XmlTag);
			foreach (var pair in Attributes) {
				writer.WriteAttributeString (pair.Key, pair.Value);
			}
			WriteNodeList (writer, Children);
			writer.WriteEndElement ();
		}
		
		public static IfStatement Read (XmlReader reader)
		{
			IfStatement result = new IfStatement ();
			if (reader.MoveToFirstAttribute ()) {
				do {
					result.SetAttribute (reader.LocalName, reader.Value);
				} while (reader.MoveToNextAttribute ());
			}
			result.Children = Node.ReadNodeList (reader, XmlTag);
			return result;
		}
	}
}

==> monodevelop_4.2.2.orig.tar.gz: monodevelop-4.2.2/src/addins/MonoDevelop.DocFood/MonoDevelop.DocFood/IfStatement.cs <==
// 
// IfStatement.cs
//  
// Author:
//       Mike Krüger <mkrueger@novell.com>
// 
// Copyright (c) 2010 Novell, Inc (http://www.novell.com)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
using System;
using System.Xml;

namespace MonoDevelop.DocFood
{
	class IfStatement : Node
	{
		public const string XmlTag = "If";
		
		public override void Run (DocGenerator generator, object member)
		{
			if (generator.EvaluateCondition (Attributes, member))
				Children.ForEach (child => child.Run (generator, member));
		}
		
		public override void Write (XmlWriter writer)
		{
			writer.WriteStartElement (XmlTag);
			foreach (var pair in Attributes) {
				writer.WriteAttributeString (pair.Key, pair.Value);
			}
			WriteNodeList (writer, Children);
			writer.WriteEndElement ();
		}
		
		public static IfStatement Read (XmlReader reader)
		{
			IfStatement result = new IfStatement ();
			if (reader.MoveToFirstAttribute ()) {
				do {
					result.SetAttribute (reader.LocalName, reader.Value);
				} while (reader.MoveToNextAttribute ());
			}
			result.Children = Node.ReadNodeList (reader, XmlTag);
			return result;
		}
	}
}
